function AndrzejakChaos23Example
%
% This source code was published as supporting material for the article:
% Ralph G. Andrzejak, Anas Espinoso, Eduardo Garca-Portugus, 
% Arthur Pewsey, Jacopo Epifanio, Marc G. Leguia, Kaspar Schindler; 
% High expectations on phase locking: Better quantifying the concentration 
% of circular data. Chaos (2023); 33 (9): 091106. 
% https://doi.org/10.1063/5.0166468
%
% If you have no access to this journal page, please visit the repository
% of our university at:
% https://doi.org/10.34810/data845
% Which contains links to a reprint.
% 
% As an exemplary application of the mean resultant length (Eq. 1) and 
% re-normalized mean resultant length (Eq. 5) this source code allows 
% you to reproduce figure 1a and 1c from the manuscript. 
%
% Please note: 
% A) Due to the random initial conditions, you will get a new realization for 
% every new run of the source code. Your results will be equivalent to the 
% figures in the paper without being identical.
%
% B) We encapsulate the calculation of the mean resultant length and re-
% normalized mean resultant length in the function MRL_RNMRL and call it 
% inside a for-loop. This makes it easy to understand and easy to use. 
% However, if execution time matters, you can use the matlab typical matrix 
% calculus and avoid that the sample size n and gamma_n (Eq. 4) are 
% determined everytime.


% We set some constants used in this particular example:
dt = 0.05; % Step size for integration of dynamics.
tmax = 50000; % Total number of samples, corresponding to 2500 time units at dt=0.05.
W=400; % Window length used for the moving average (20 time units). See caption of figure 1.
omegasA = [5.57; 10.17; 3.12; 19.18; 5.89]; % Omegas for dynamics A, first line in table I. 
omegasB = [5.19; 8.95; 3.16; 0.45; 0.72; 1.71; 1.11; 7.78; 3.79; 13.33]; % Omegas for dynamics B, first line in table II.
KA = zeros(tmax+W-1,1); % Coupling for system A. 
% We generate a total of 50399 samples and plot from sample 400 onward.
% This accounts for the moving average smoothing.
KB = zeros(tmax+W-1,1); KB((tmax/2)+W-1:end) = 2.7; % Coupling for system B



% Generate dynamics A and B
[Allthetas_SystemA] =GenerateCoupledOscillators(omegasA,KA,dt);
[Allthetas_SystemB] =GenerateCoupledOscillators(omegasB,KB,dt);

% Calculate mean resultant length and re-normalized mean resultant length
% across all samples for both dynamics. 

% Allocate result vectors for both dynamics
RnA = zeros(tmax+W-1,1); % Mean resultant length system A
TnA = zeros(tmax+W-1,1); % Re-normalized mean resultant length system A
RnB = zeros(tmax+W-1,1); % Mean resultant length system B
TnB = zeros(tmax+W-1,1); % Re-normalized mean resultant length system B

for sample =1:tmax+W-1
   [RnA(sample), TnA(sample)] = MRL_RNMRL(Allthetas_SystemA(sample,:));
   [RnB(sample), TnB(sample)] = MRL_RNMRL(Allthetas_SystemB(sample,:));
   
end

% Application of moving average of 20 time units 
RnA = movingaverage(RnA,W);
TnA = movingaverage(TnA,W);
RnB = movingaverage(RnB,W);
TnB = movingaverage(TnB,W);

% Plotting the results in the same style as in the manuscript
figure(1);
clf;
color_A = [84,222,253]/255;
color_B = [204,41,54]/255;

subplot(211);
lh=plot((W:tmax+W-1)/20,RnB(W:tmax+W-1));
set(lh,'color',color_B);
hold on;
lh=plot((W:tmax+W-1)/20,RnA(W:tmax+W-1));
set(lh,'color',color_A);
yl=ylabel('$\bar{R}_n$');
set(yl,'interpreter','latex','fontsize',19);
yl=xlabel('time [a.u.]');
set(yl,'interpreter','latex','fontsize',14);
ylim([0 0.6]);
xlim([1 2500]);
thl=text(-0.115, .9,'1a','units','normalized');
set(thl,'FontName','Arial','Fontsize',15,'Fontweight','bold');
grid on;

subplot(212);
lh=plot((W:tmax+W-1)/20,TnB(W:tmax+W-1));
set(lh,'color',color_B);
hold on;
lh=plot((W:tmax+W-1)/20,TnA(W:tmax+W-1));
set(lh,'color',color_A);
yl=ylabel('$\bar{T}_n$');
set(yl,'interpreter','latex','fontsize',19);
yl=xlabel('time [a.u.]');
set(yl,'interpreter','latex','fontsize',14);
ylim([-.1 0.6]);
xlim([1 2500]);
thl=text(-0.115, .9,'1c','units','normalized');
set(thl,'FontName','Arial','Fontsize',15,'Fontweight','bold');
grid on;

