function [Allthetas] =GenerateCoupledOscillators(omegas,K,dt)
%
% This source code was published as supporting material for the article:
% Ralph G. Andrzejak, Anas Espinoso, Eduardo Garca-Portugus, 
% Arthur Pewsey, Jacopo Epifanio, Marc G. Leguia, Kaspar Schindler; 
% High expectations on phase locking: Better quantifying the concentration 
% of circular data. Chaos (2023); 33 (9): 091106. 
% https://doi.org/10.1063/5.0166468
%
% If you have no access to this journal page, please visit the repository
% of our university at:
% https://doi.org/10.34810/data845
% Which contains links to a reprint.
%
% 
% This function allows you to generate the phases of a group of all-to-all
% coupled phase oscillators using Eq. 3 of the manuscript. The inputs are
% the natural frequencies in the vector omegas and the time dependent coupling 
% in the vector K. The number of oscillators is concluded from the number 
% of provided omegas. The number of samples is concluded from the length of
% the vector K. If K contains only zeros, Eq. 3 reduces to Eq. 2 and the
% source generates a group of uncoupled oscillators.
% Input 
% omegas: array of natural frequencies
% K: time dependent vector of coupling strength
% dt: sampling time used for the integration of the dynamics
% Output 
% Allthetas: Matrix of all phases of dimension 
% (number of samples x number of oscillators)



% determine number of oscillators and samples.
n = length(omegas);
tmax = length(K);
% initialize system with random initial conditions drawn from the circular 
% uniform distribution.
theta = rand(n,1)*2*pi;
% Allocate memory for all phases
Allthetas = zeros(tmax,n);
% Allocate (n x n) identity matrix for all-to-all coupling
GBase = ones(n,n);

for sample =1:tmax
    G = GBase *K(sample)/n;
    k1 = dt*DifferentialEquation(theta,G,omegas);
    k2 = dt*DifferentialEquation(theta+k1/2,G,omegas);
    k3 = dt*DifferentialEquation(theta+k2/2,G,omegas);
    k4 = dt*DifferentialEquation(theta+k3,G,omegas);
    theta = theta + k1/6+k2/3+k3/3+k4/6;
    theta = mod(theta,2*pi);
    Allthetas(sample,:)=theta;    
end


function dtheta = DifferentialEquation(theta,G,omegas)
diffm=bsxfun(@minus,theta,theta');
dtheta = omegas-sum(sin(diffm).*G,2);


